@@ -24,7 +24,7 @@ nlsList.selfStart <-
   m <- call(as.character(marg))
   args <- lapply(names(formals(eval(marg))), as.name)
   args[[1]] <- getCovariateFormula(data)[[2]]
-  m[1 + seq(along = args)] <- args
+  m[1 + seq_along(args)] <- args
   form <- formula(data)
   form[[3]][[2]] <- m
   mCall$model <- form
@@ -60,8 +60,9 @@ nlsList.formula <-
     } else if (length(level) > 1) {
       stop("Multiple levels not allowed")
     }
-    model <- eval(parse(text = paste(deparse(model[[2]]),
-                        deparse(getCovariateFormula(model)[[2]]), sep = "~")))
+    model <- eval(parse(text = paste(paste(deparse(model[[2]]), collapse=" "),
+                        paste(deparse(getCovariateFormula(model)[[2]]), collapse=" "),
+			sep = "~")))
     groups <- getGroups(data, form = grpForm, level = level)[drop = TRUE]
   }
   if (is.null(start) && is.null(attr(data, "parameters"))) {
